@@ -56,6 +56,7 @@ __all__ = (
     "ListedUserTypeDef",
     "PaginatorConfigTypeDef",
     "PosixProfileTypeDef",
+    "ProtocolDetailsTypeDef",
     "SshPublicKeyTypeDef",
     "TagTypeDef",
     "TestIdentityProviderResponseTypeDef",
@@ -166,6 +167,7 @@ _OptionalDescribedServerTypeDef = TypedDict(
     "_OptionalDescribedServerTypeDef",
     {
         "Certificate": str,
+        "ProtocolDetails": "ProtocolDetailsTypeDef",
         "Domain": DomainType,
         "EndpointDetails": "EndpointDetailsTypeDef",
         "EndpointType": EndpointTypeType,
@@ -439,6 +441,14 @@ class PosixProfileTypeDef(_RequiredPosixProfileTypeDef, _OptionalPosixProfileTyp
     pass
 
 
+ProtocolDetailsTypeDef = TypedDict(
+    "ProtocolDetailsTypeDef",
+    {
+        "PassiveIp": str,
+    },
+    total=False,
+)
+
 SshPublicKeyTypeDef = TypedDict(
     "SshPublicKeyTypeDef",
     {
